@@ -2,9 +2,12 @@
 from robster.model import LinearModel
 
 class SingleLayerPerceptron:
-  def __init__(self, epochs, mini_batch, MODEL = LinearModel,learning_rate = 0.001, report = 1):
-    self.epochs = epochs; self.mini_batch = mini_batch; self.learning_rate = learning_rate; self.report=report
-    self.repo = ""; self.MODEL = MODEL
+  def __init__(self, epochs, mini_batch, MODEL = LinearModel, learning_rate = 0.001, report = 1):
+    self.epochs = epochs
+    self.mini_batch = mini_batch
+    self.learning_rate = learning_rate
+    self.report=report
+    self.MODEL = MODEL
 
 
   def fit(self, X, y):
@@ -23,7 +26,8 @@ class SingleLayerPerceptron:
         output, aux_nn = self.model.forward(X_train)
         loss, aux_pp = self.model.forward_postproc(output, y_train)
         acc = self.model.eval_accuracy(output, y_train)
-        losses.append(loss); accs.append(acc)
+        losses.append(loss)
+        accs.append(acc)
 
         #
         G_loss = 1
